Learn R Programming

GetDFPData2 (version 0.6.2)

get_info_companies: Returns a up to date table with information about B3 companies

Description

Imports a dataset from cvm <http://dados.cvm.gov.br/>, containing up to date information about companies, active or not.

Usage

get_info_companies(cache_folder = "gdfpd2_cache")

Value

A dataframe with information about available companies in the database

Arguments

cache_folder

Path of cache folder to keep memoise and zip files

Examples

Run this code

if (FALSE)  # keep cran check fast
df_info <- get_info_companies()
str(df_info)

Run the code above in your browser using DataLab