powered by
Helps users search for a company
search_company(char_to_search, cache_folder = "gdfpd2_cache")
A dataframe with information about available companies in the CVM database
Character for partial matching
Path of cache folder to keep memoise and zip files
if (FALSE) # dontrun: keep cran check fast df <- search_company('petrobras')
Run the code above in your browser using DataLab