powered by
Imports a dataset from cvm <http://dados.cvm.gov.br/>, containing up to date information about companies, active or not.
get_info_companies(cache_folder = "gdfpd2_cache")
A dataframe with information about available companies in the database
Path of cache folder to keep memoise and zip files
if (FALSE) # keep cran check fast df_info <- get_info_companies() str(df_info)
Run the code above in your browser using DataLab